@@ -73,10 +73,15 @@ class Data_Organizer(object):
         if self.resampling != None:
             if isinstance(img_arr, np.ndarray):
                 x = torch.tensor(img_arr.copy())
+            else:
+                x = img_arr
             
             if isinstance(seg_arr, np.ndarray):
                 y = torch.tensor(seg_arr.copy())
-                
+            
+            else:
+                y = seg_arr
+
             if self.mode == 'train' :
                 result = self.resampling(torch.vstack((x, y.unsqueeze(0))), save_dict)
                 x = result[:-1]
