@@ -23,14 +23,14 @@ class Normalizer(object):
         if self.percentile != None:
             images = self.percentile_clipping(images)
         n_modalities, nx, ny, nz = images.shape
-        mmean = torch.mean(images.view(n_modalities, -1), -1, True).view(n_modalities,1,1,1)
-        mstd = torch.std(images.view(n_modalities, -1), -1, True).view(n_modalities,1,1,1)
+        mmean = torch.mean(images.reshape(n_modalities, -1), -1, True).reshape(n_modalities,1,1,1)
+        mstd = torch.std(images.reshape(n_modalities, -1), -1, True).reshape(n_modalities,1,1,1)
         return (images - mmean) / mstd
         
     
     def percentile_clipping(self,images):
         n_modalities, nx, ny, nz = images.shape
-        images = images.view(n_modalities, -1)
+        images = images.reshape(n_modalities, -1)
         vals, indices = torch.sort(images, -1)
         upper_index = indices[:, int(indices.shape[1] * self.percentile[1]):]
         lower_index = indices[:, :int(indices.shape[1] * self.percentile[0])]
@@ -41,7 +41,7 @@ class Normalizer(object):
             images[i, upper_index[i]] = upper_val[i]
             images[i, lower_index[i]] = lower_val[i]
         
-        return images.view(n_modalities, nx, ny, nz)
+        return images.reshape(n_modalities, nx, ny, nz)
 
 
 class Cropping(object):
