@@ -1,6 +1,6 @@
 import numpy as np
 import torch
-
+import time
 
 def is_overlap(points, current_point):
     if points[current_point[0], current_point[1], current_point[2], current_point[3]] != 0:
@@ -31,6 +31,7 @@ def get_random_sample(points, candidates, batch_index):
     return points
 """
 
+"""
 
 def get_random_sample(points, candidates, batch_index):
     n_candidates = len(candidates[0])
@@ -43,22 +44,22 @@ def get_random_sample(points, candidates, batch_index):
     point = [batch_index, x, y, z]
     points[point[0], point[1], point[2], point[3]] = 1
     return points
-
+"""
 def point_sampler(target, output = None, positive_points = None, negative_points = None):
     # target shpae, prev_seg => (batch, x, y, z)
     # positive_points, negative_points => (n, 4) [(batch_index, x_index, y_index, z_index), ...과 같은 방식], 입력 시 Transpose를 이용해 쉽게 넣을 수 있다.
     # 초기값 세팅
     bs, x, y, z = target.shape
-    if output == None:
+    if type(output) == type(None):
         prev_seg = torch.zeros(target.shape).to(target.device.index)
     
     else:
         prev_seg = (output[:, 0] > 0.5).long()
         
-    if positive_points == None:
+    if type(positive_points) == type(None):
         positive_points = torch.zeros(target.shape).to(target.device.index)
     
-    if negative_points == None:
+    if type(negative_points) == type(None):
         negative_points = torch.zeros(target.shape).to(target.device.index)
     
     for batch_index in range(bs):
@@ -68,14 +69,18 @@ def point_sampler(target, output = None, positive_points = None, negative_points
 
         elif prev_seg[batch_index].sum() >= target[batch_index].sum():
             # negative sampling
+            cand_time = time.time()
             candidates = torch.where((target * (prev_seg != target)) == 0)
+            print("find cand", time.time()- cand_time)
             n_candidates = len(candidates[0])
             index = torch.randint(low = 0, high = n_candidates, size = (1,))
             negative_points[batch_index, candidates[-3][index], candidates[-2][index],candidates[-1][index]] = 1
 
         elif prev_seg[batch_index].sum() < target[batch_index].sum():
             # positive sampling
+            cand_time = time.time()
             candidates = torch.where((target * (prev_seg != target)) == 1)
+            print("find cand", time.time()- cand_time)
             n_candidates = len(candidates[0])
             index = torch.randint(low = 0, high = n_candidates, size = (1,))
             positive_points[batch_index, candidates[-3][index], candidates[-2][index],candidates[-1][index]] = 1
