@@ -186,7 +186,7 @@ class Interactive_Trainer(Trainer):
                     print('prev_seg', time.time()- prev_seg_time)
                     ps_time = time.time()
                     positive_points, negative_points = point_sampler(seg, prev_seg, positive_points, negative_points)
-                    out_time = time.time
+                    out_time = time.time()
                     print('ps time', time.time()- ps_time)
                     output = self.model(images, positive_points, negative_points, prev_seg)
                     loss_time = time.time()
